@@ -18,8 +18,8 @@
 #ifndef DIFFMODEL_H
 #define DIFFMODEL_H
 
-#include <QtCore/QObject>
-#include <QtCore/QStringList>
+#include <QObject>
+#include <QStringList>
 
 #include "diffhunk.h"
 #include "kompare.h"
@@ -145,7 +145,7 @@ private:
 
 	bool m_blended;
 
-private slots:
+private Q_SLOTS:
 	void slotDifferenceApplied( Difference* diff );
 };
 
