@@ -18,7 +18,7 @@
 #ifndef DIFFSETTINGS_H
 #define DIFFSETTINGS_H
 
-#include <QtCore/QStringList>
+#include <QStringList>
 #include <QWidget>
 
 #include "kompare.h"
@@ -29,12 +29,12 @@ class DIFF2_EXPORT  DiffSettings : public SettingsBase
 {
 Q_OBJECT
 public:
-	DiffSettings( QWidget* parent );
+	explicit DiffSettings(QWidget* parent);
 	virtual ~DiffSettings();
 public:
 	// some virtual functions that will be overloaded from the base class
-	virtual void loadSettings( KConfig* config );
-	virtual void saveSettings( KConfig* config );
+	void loadSettings( KConfig* config ) Q_DECL_OVERRIDE;
+	void saveSettings( KConfig* config ) Q_DECL_OVERRIDE;
 
 public:
 	QString m_diffProgram;
